-- Changes for differential expression.


-- default value null
ALTER TABLE ANALYSIS_RESULT_SET
  ADD COLUMN QVALUE_THRESHOLD_FOR_STORAGE DOUBLE;

-- add new table supporting pvalue distributions
CREATE TABLE PVALUE_DISTRIBUTION (
  ID         BIGINT  NOT NULL AUTO_INCREMENT,
  NUM_BINS   INTEGER NOT NULL,
  BIN_COUNTS BLOB    NOT NULL,
  PRIMARY KEY (ID)
);
ALTER TABLE ANALYSIS_RESULT_SET
  ADD COLUMN PVALUE_DISTRIBUTION_FK BIGINT UNIQUE;
ALTER TABLE ANALYSIS_RESULT_SET
  ADD INDEX FKC510E6634F13DFD5 (PVALUE_DISTRIBUTION_FK),
  ADD CONSTRAINT FKC510E6634F13DFD5 FOREIGN KEY (PVALUE_DISTRIBUTION_FK) REFERENCES PVALUE_DISTRIBUTION (ID);

-- change column name in DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT to be easier to work with in code. Do in two steps so we have both columns, briefly:
-- first add new column, RESULT_SET_FK
ALTER TABLE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
  ADD COLUMN RESULT_SET_FK BIGINT NOT NULL;
UPDATE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
SET RESULT_SET_FK = EXPRESSION_ANALYSIS_RESULT_SET_FK;
ALTER TABLE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
  ADD INDEX DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_RESULT_SET_FKC (RESULT_SET_FK),
  ADD CONSTRAINT DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_RESULT_SET_FKC FOREIGN KEY (RESULT_SET_FK) REFERENCES ANALYSIS_RESULT_SET (ID);
-- re-run that update as necessary until code is switched:
UPDATE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
SET RESULT_SET_FK = EXPRESSION_ANALYSIS_RESULT_SET_FK
WHERE RESULT_SET_FK IS NULL;

-- same for hit lists
ALTER TABLE HIT_LIST_SIZE
  ADD COLUMN RESULT_SET_FK BIGINT NOT NULL;
SET FOREIGN_KEY_CHECKS = 0;
ALTER TABLE HIT_LIST_SIZE
  ADD INDEX HIT_LIST_SIZE_RESULT_SET_FKC (RESULT_SET_FK),
  ADD CONSTRAINT HIT_LIST_SIZE_RESULT_SET_FKC FOREIGN KEY (RESULT_SET_FK) REFERENCES ANALYSIS_RESULT_SET (ID);
SET FOREIGN_KEY_CHECKs = 1;
UPDATE HIT_LIST_SIZE
SET RESULT_SET_FK = EXPRESSION_ANALYSIS_RESULT_SET_FK
WHERE RESULT_SET_FK IS NULL; -- run this as needed up to final rollout.

--
CREATE TABLE META_ANALYSES2RESULT_SETS_INCLUDED (
  META_ANALYSES_FK        BIGINT NOT NULL,
  RESULT_SETS_INCLUDED_FK BIGINT NOT NULL,
  PRIMARY KEY (META_ANALYSES_FK, RESULT_SETS_INCLUDED_FK)
);
ALTER TABLE META_ANALYSES2RESULT_SETS_INCLUDED
  ADD INDEX EXPRESSION_ANALYSIS_RESULT_SET_META_ANALYSES_FKC (META_ANALYSES_FK),
  ADD CONSTRAINT EXPRESSION_ANALYSIS_RESULT_SET_META_ANALYSES_FKC FOREIGN KEY (META_ANALYSES_FK) REFERENCES ANALYSIS (ID);
ALTER TABLE META_ANALYSES2RESULT_SETS_INCLUDED
  ADD INDEX FK58643060635B349F (RESULT_SETS_INCLUDED_FK),
  ADD CONSTRAINT FK58643060635B349F FOREIGN KEY (RESULT_SETS_INCLUDED_FK) REFERENCES ANALYSIS_RESULT_SET (ID);
INSERT INTO META_ANALYSES2RESULT_SETS_INCLUDED (META_ANALYSES_FK, RESULT_SETS_INCLUDED_FK) SELECT
                                                                                             GENE_DIFFERENTIAL_EXPRESSION_META_ANALYSES_FK,
                                                                                             RESULT_SETS_INCLUDED_FK
                                                                                           FROM
                                                                                             GENE_DIFFERENTIAL_EXPRESSION_META_ANALYSES2RESULT_SETS_INCLU;

-- when all is well, drop EXPRESSION_EXPERIMENT_RESULT_SET_FK column
ALTER TABLE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
  DROP KEY DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_EXPRESSION_ANALYSISC;
ALTER TABLE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
  DROP FOREIGN KEY DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_EXPRESSION_ANALYSISC;
ALTER TABLE DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT
  DROP COLUMN EXPRESSION_EXPERIMENT_RESULT_SET_FK;

ALTER TABLE HIT_LIST_SIZE
  DROP KEY HIT_SIZE_EXPRESSION_ANALYSIS_RESULT_SET_FKC;
ALTER TABLE HIT_LIST_SIZE
  DROP FOREIGN KEY DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_EXPRESSION_ANALYSISC;
ALTER TABLE HIT_LIST_SIZE
  DROP COLUMN HIT_LIST_SIZE_RESULT_SET_FK;

-- no longer needed.
DROP TABLE GENE_DIFFERENTIAL_EXPRESSION_META_ANALYSES2RESULT_SETS_INCLU;

-- Now, remove all results that are above the threshold we want to use by default.
DELETE c, r FROM
  DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT r INNER JOIN CONTRAST c ON c.DIFFERENTIAL_EXPRESSION_ANALYSIS_RESULT_FK = r.ID
WHERE r.PVALUE >= 0.05;

-- drop more unneded columns 
ALTER TABLE RAT_PROBE_CO_EXPRESSION
  DROP KEY PROBE2_PROBE_COEXPRESSION_METRIC_FKC;
ALTER TABLE OTHER_PROBE_CO_EXPRESSION
  DROP KEY PROBE2_PROBE_COEXPRESSION_METRIC_FKC;
ALTER TABLE HUMAN_PROBE_CO_EXPRESSION
  DROP KEY PROBE2_PROBE_COEXPRESSION_METRIC_FKC;
ALTER TABLE MOUSE_PROBE_CO_EXPRESSION
  DROP KEY PROBE2_PROBE_COEXPRESSION_METRIC_FKC;
ALTER TABLE RAT_PROBE_CO_EXPRESSION
  DROP COLUMN METRIC_FK;
ALTER TABLE OTHER_PROBE_CO_EXPRESSION
  DROP COLUMN METRIC_FK;
ALTER TABLE HUMAN_PROBE_CO_EXPRESSION
  DROP COLUMN METRIC_FK;
ALTER TABLE MOUSE_PROBE_CO_EXPRESSION
  DROP COLUMN METRIC_FK;