-- changes for new coexpression setup.

DROP TABLE IF EXISTS HUMAN_GENE_COEXPRESSION;
DROP TABLE IF EXISTS MOUSE_GENE_COEXPRESSION;
DROP TABLE IF EXISTS RAT_GENE_COEXPRESSION;
DROP TABLE IF EXISTS OTHER_GENE_COEXPRESSION;

CREATE TABLE HUMAN_GENE_COEXPRESSION (
  ID                 BIGINT NOT NULL,
  POSITIVE           TINYINT,
  SUPPORT            INTEGER,
  FIRST_GENE_FK      BIGINT NOT NULL,
  SECOND_GENE_FK     BIGINT NOT NULL,
  SUPPORT_DETAILS_FK BIGINT,
  PRIMARY KEY (ID)
);
CREATE TABLE MOUSE_GENE_COEXPRESSION (
  ID                 BIGINT NOT NULL,
  POSITIVE           TINYINT,
  SUPPORT            INTEGER,
  FIRST_GENE_FK      BIGINT NOT NULL,
  SECOND_GENE_FK     BIGINT NOT NULL,
  SUPPORT_DETAILS_FK BIGINT,
  PRIMARY KEY (ID)
);
CREATE TABLE RAT_GENE_COEXPRESSION (
  ID                 BIGINT NOT NULL,
  POSITIVE           TINYINT,
  SUPPORT            INTEGER,
  FIRST_GENE_FK      BIGINT NOT NULL,
  SECOND_GENE_FK     BIGINT NOT NULL,
  SUPPORT_DETAILS_FK BIGINT,
  PRIMARY KEY (ID)
);
CREATE TABLE OTHER_GENE_COEXPRESSION (
  ID                 BIGINT NOT NULL,
  POSITIVE           TINYINT,
  SUPPORT            INTEGER,
  FIRST_GENE_FK      BIGINT NOT NULL,
  SECOND_GENE_FK     BIGINT NOT NULL,
  SUPPORT_DETAILS_FK BIGINT,
  PRIMARY KEY (ID)
);

-- we don't really need the second gene constraint, and it adds an index.
ALTER TABLE HUMAN_GENE_COEXPRESSION
  ADD CONSTRAINT FKF9E6557F90452155 FOREIGN KEY (FIRST_GENE_FK) REFERENCES CHROMOSOME_FEATURE (ID);
ALTER TABLE HUMAN_GENE_COEXPRESSION
  ADD INDEX FKF9E6557FC02BF5B4 (SUPPORT_DETAILS_FK),
  ADD CONSTRAINT FKF9E6557FC02BF5B4 FOREIGN KEY (SUPPORT_DETAILS_FK) REFERENCES HUMAN_LINK_SUPPORT_DETAILS (ID);
ALTER TABLE MOUSE_GENE_COEXPRESSION
  ADD CONSTRAINT FKFC61C4F790452155 FOREIGN KEY (FIRST_GENE_FK) REFERENCES CHROMOSOME_FEATURE (ID);
ALTER TABLE MOUSE_GENE_COEXPRESSION
  ADD INDEX FKFC61C4F7C02BF5B4 (SUPPORT_DETAILS_FK),
  ADD CONSTRAINT FKFC61C4F7C02BF5B4 FOREIGN KEY (SUPPORT_DETAILS_FK) REFERENCES MOUSE_LINK_SUPPORT_DETAILS (ID);
ALTER TABLE RAT_GENE_COEXPRESSION
  ADD CONSTRAINT FKDE59FC7790452155 FOREIGN KEY (FIRST_GENE_FK) REFERENCES CHROMOSOME_FEATURE (ID);
ALTER TABLE RAT_GENE_COEXPRESSION
  ADD INDEX FKDE59FC77C02BF5B4 (SUPPORT_DETAILS_FK),
  ADD CONSTRAINT FKDE59FC77C02BF5B4 FOREIGN KEY (SUPPORT_DETAILS_FK) REFERENCES RAT_LINK_SUPPORT_DETAILS (ID);
ALTER TABLE OTHER_GENE_COEXPRESSION
  ADD CONSTRAINT FK74B9A3E290452155 FOREIGN KEY (FIRST_GENE_FK) REFERENCES CHROMOSOME_FEATURE (ID);
ALTER TABLE OTHER_GENE_COEXPRESSION
  ADD INDEX FK74B9A3E2C02BF5B4 (SUPPORT_DETAILS_FK),
  ADD CONSTRAINT FK74B9A3E2C02BF5B4 FOREIGN KEY (SUPPORT_DETAILS_FK) REFERENCES OTHER_LINK_SUPPORT_DETAILS (ID);

-- "MySQL requires that foreign key columns be indexed" we still get the SECOND_GENE_FK index even though didn't add it explicitly.
-- http://dev.mysql.com/doc/refman/5.0/en/constraint-foreign-key.html
ALTER TABLE HUMAN_GENE_COEXPRESSION
  ADD INDEX hfgsg (FIRST_GENE_FK, SECOND_GENE_FK);
ALTER TABLE MOUSE_GENE_COEXPRESSION
  ADD INDEX mfgsg (FIRST_GENE_FK, SECOND_GENE_FK);
ALTER TABLE RAT_GENE_COEXPRESSION
  ADD INDEX rfgsg (FIRST_GENE_FK, SECOND_GENE_FK);
ALTER TABLE OTHER_GENE_COEXPRESSION
  ADD INDEX ofgsg (FIRST_GENE_FK, SECOND_GENE_FK);

DROP TABLE IF EXISTS HUMAN_EXPERIMENT_COEXPRESSION;
DROP TABLE IF EXISTS MOUSE_EXPERIMENT_COEXPRESSION;
DROP TABLE IF EXISTS RAT_EXPERIMENT_COEXPRESSION;
DROP TABLE IF EXISTS OTHER_EXPERIMENT_COEXPRESSION;

CREATE TABLE HUMAN_EXPERIMENT_COEXPRESSION (
  ID            BIGINT NOT NULL,
  EXPERIMENT_FK BIGINT NOT NULL,
  LINK_FK       BIGINT NOT NULL,
  GENE1_FK      BIGINT NOT NULL,
  GENE2_FK      BIGINT NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE MOUSE_EXPERIMENT_COEXPRESSION (
  ID            BIGINT NOT NULL,
  EXPERIMENT_FK BIGINT NOT NULL,
  LINK_FK       BIGINT NOT NULL,
  GENE1_FK      BIGINT NOT NULL,
  GENE2_FK      BIGINT NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE RAT_EXPERIMENT_COEXPRESSION (
  ID            BIGINT NOT NULL,
  EXPERIMENT_FK BIGINT NOT NULL,
  LINK_FK       BIGINT NOT NULL,
  GENE1_FK      BIGINT NOT NULL,
  GENE2_FK      BIGINT NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE OTHER_EXPERIMENT_COEXPRESSION (
  ID            BIGINT NOT NULL,
  EXPERIMENT_FK BIGINT NOT NULL,
  LINK_FK       BIGINT NOT NULL,
  GENE1_FK      BIGINT NOT NULL,
  GENE2_FK      BIGINT NOT NULL,
  PRIMARY KEY (ID)
);

ALTER TABLE HUMAN_EXPERIMENT_COEXPRESSION
  ADD INDEX ECL1EFK (EXPERIMENT_FK, GENE1_FK, GENE2_FK),
  ADD CONSTRAINT ECL1EFK FOREIGN KEY (EXPERIMENT_FK) REFERENCES INVESTIGATION (ID);
ALTER TABLE MOUSE_EXPERIMENT_COEXPRESSION
  ADD INDEX ECL2EFK (EXPERIMENT_FK, GENE1_FK, GENE2_FK),
  ADD CONSTRAINT ECL2EFK FOREIGN KEY (EXPERIMENT_FK) REFERENCES INVESTIGATION (ID);
ALTER TABLE RAT_EXPERIMENT_COEXPRESSION
  ADD INDEX ECL3EFK (EXPERIMENT_FK, GENE1_FK, GENE2_FK),
  ADD CONSTRAINT ECL3EFK FOREIGN KEY (EXPERIMENT_FK) REFERENCES INVESTIGATION (ID);
ALTER TABLE OTHER_EXPERIMENT_COEXPRESSION
  ADD INDEX ECL4EFK (EXPERIMENT_FK, GENE1_FK, GENE2_FK),
  ADD CONSTRAINT ECL4EFK FOREIGN KEY (EXPERIMENT_FK) REFERENCES INVESTIGATION (ID);

SET foreign_key_checks = 0;
DROP TABLE IF EXISTS HUMAN_LINK_SUPPORT_DETAILS;
DROP TABLE IF EXISTS MOUSE_LINK_SUPPORT_DETAILS;
DROP TABLE IF EXISTS RAT_LINK_SUPPORT_DETAILS;
DROP TABLE IF EXISTS OTHER_LINK_SUPPORT_DETAILS;

CREATE TABLE HUMAN_LINK_SUPPORT_DETAILS (
  ID    BIGINT     NOT NULL,
  BYTES MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE MOUSE_LINK_SUPPORT_DETAILS (
  ID    BIGINT     NOT NULL,
  BYTES MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE RAT_LINK_SUPPORT_DETAILS (
  ID    BIGINT     NOT NULL,
  BYTES MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);
CREATE TABLE OTHER_LINK_SUPPORT_DETAILS (
  ID    BIGINT     NOT NULL,
  BYTES MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);
SET foreign_key_checks = 1;

DROP TABLE IF EXISTS GENE_COEX_TESTED_IN;
CREATE TABLE GENE_COEX_TESTED_IN (
  ID        BIGINT     NOT NULL,
  NUM_TESTS SMALLINT   NOT NULL,
  BYTES     MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);

DROP TABLE IF EXISTS COEXPRESSION_NODE_DEGREE;
CREATE TABLE COEXPRESSION_NODE_DEGREE (
  GENE_ID        BIGINT     NOT NULL,
  LINK_COUNTS    MEDIUMBLOB NOT NULL,
  REL_LINK_RANKS MEDIUMBLOB NOT NULL,
  PRIMARY KEY (GENE_ID)
);

-- late-breaking change...
ALTER TABLE COEXPRESSION_NODE_DEGREE
  ADD COLUMN LINK_COUNTS_POS MEDIUMBLOB NOT NULL;
ALTER TABLE COEXPRESSION_NODE_DEGREE
  ADD COLUMN LINK_COUNTS_NEG MEDIUMBLOB NOT NULL;
ALTER TABLE COEXPRESSION_NODE_DEGREE
  ADD COLUMN REL_LINK_RANKS_POS MEDIUMBLOB NOT NULL;
ALTER TABLE COEXPRESSION_NODE_DEGREE
  ADD COLUMN REL_LINK_RANKS_NEG MEDIUMBLOB NOT NULL;
-- temporary
UPDATE COEXPRESSION_NODE_DEGREE
SET LINK_COUNTS_POS = LINK_COUNTS;
UPDATE COEXPRESSION_NODE_DEGREE
SET REL_LINK_RANKS_POS = REL_LINK_RANKS;


DROP TABLE IF EXISTS GENE_COEX_GENES;
CREATE TABLE GENE_COEX_GENES (
  ID    BIGINT     NOT NULL,
  BYTES MEDIUMBLOB NOT NULL,
  PRIMARY KEY (ID)
);

-- later: remove unused data.

DROP TABLE HUMAN_PROBE_CO_EXPRESSION;
DROP TABLE MOUSE_PROBE_CO_EXPRESSION;
DROP TABLE RAT_PROBE_CO_EXPRESSION;
DROP TABLE OTHER_PROBE_CO_EXPRESSION;

-- This column is not needed as we killed the mult-experiment analysis concept. (it only existed for coexpression)
ALTER TABLE ANALYSIS
  DROP COLUMN EXPRESSION_EXPERIMENT_SET_ANALYZED_FK;

-- not used
ALTER TABLE ANALYSIS
  DROP COLUMN STRINGENCY;
ALTER TABLE ANALYSIS
  DROP COLUMN VIEWED_ANALYSIS_FK;
ALTER TABLE ANALYSIS
  DROP COLUMN ENABLED;

-- eventually...
DROP TABLE HUMAN_GENE_CO_EXPRESSION;
DROP TABLE MOUSE_GENE_CO_EXPRESSION;
DROP TABLE RAT_GENE_CO_EXPRESSION;
DROP TABLE OTHER_GENE_CO_EXPRESSION;
DROP TABLE GENE_COEXPRESSION_NODE_DEGREE;
